==> haskell-ci-0.16.3-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ci.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-haskell-ci-z-haskell-ci-internal
version:              0.16.3
package-name:         haskell-ci
lib-name:             haskell-ci-internal
id:
    haskell-ci-0.16.3-Kyt8Ww5UqXiDHX5dr5T2LA-haskell-ci-internal

key:
    haskell-ci-0.16.3-Kyt8Ww5UqXiDHX5dr5T2LA-haskell-ci-internal

license:              GPL-3.0-or-later
maintainer:           hvr@gnu.org
author:               Herbert Valerio Riedel, Oleg Grenrus
homepage:             https://haskell-ci.rtfd.org/
synopsis:             Cabal package script generator for Travis-CI
description:
    Script generator (@haskell-ci@) for
    [GitHub Actions](https://docs.github.com/en/actions) and
    [Travis-CI](https://travis-ci.org/)
    for continuous-integration testing of Haskell Cabal packages.

    Included features (not limited to):

    * Multiple GHC support
    * Dependency caching
    * cabal.project support (see [Nix-style local builds documentation](https://cabal.readthedocs.io/en/latest/nix-local-build-overview.html))
    * Runs tests and builds benchmarks
    * Generates Haddocks
    * GHCJS support
    * building with specific constraints

    === Quick Start Guide

    Add a @tested-with@ line to your @.cabal@ file (e.g. @tested-with: GHC == 8.0.2 || == 8.2.2@) and then run @haskell-ci yourpackage.cabal -o .travis.yml@ to generate the Travis-CI job script.

    See @haskell-ci --help@ for more information.

category:             Development
abi:                  5ff80ba313ac9e3e92db182828151f4b
exposed-modules:
    HaskellCI HaskellCI.Auxiliary HaskellCI.Bash
    HaskellCI.Bash.Template HaskellCI.Cabal HaskellCI.Cli
    HaskellCI.Compiler HaskellCI.Config HaskellCI.Config.Components
    HaskellCI.Config.ConstraintSet HaskellCI.Config.CopyFields
    HaskellCI.Config.Docspec HaskellCI.Config.Doctest
    HaskellCI.Config.Dump HaskellCI.Config.Empty HaskellCI.Config.Folds
    HaskellCI.Config.HLint HaskellCI.Config.Installed
    HaskellCI.Config.Jobs HaskellCI.Config.PackageScope
    HaskellCI.Config.Ubuntu HaskellCI.Config.Validity
    HaskellCI.Diagnostics HaskellCI.Error HaskellCI.Ghcup
    HaskellCI.GitConfig HaskellCI.GitHub HaskellCI.GitHub.Yaml
    HaskellCI.HeadHackage HaskellCI.Jobs HaskellCI.List
    HaskellCI.MonadErr HaskellCI.Newtypes HaskellCI.OptionsGrammar
    HaskellCI.OptparseGrammar HaskellCI.Package HaskellCI.ParsecUtils
    HaskellCI.Prelude HaskellCI.Sh HaskellCI.ShVersionRange
    HaskellCI.TestedWith HaskellCI.Tools HaskellCI.Travis
    HaskellCI.Travis.Yaml HaskellCI.VersionInfo HaskellCI.YamlSyntax

import-dirs:          /usr/lib/ghc-9.4.8/site-local/haskell-ci-0.16.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/haskell-ci-0.16.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/haskell-ci-0.16.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ci
hs-libraries:
    HShaskell-ci-0.16.3-Kyt8Ww5UqXiDHX5dr5T2LA-haskell-ci-internal

depends:
    Cabal-syntax-3.8.1.0 HsYAML-0.2.1.4-CH4pJWTLtC0HUkNslG781g
    ShellCheck-0.11.0-ECIJOeshZGGH72rBHTO8fr
    aeson-2.1.2.1-HPwo2VO3hzcFr4fiGB5Oro
    attoparsec-0.14.4-4svHBw0u1Cc40MQ1AjsKLc base-4.17.2.1
    base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp
    base16-bytestring-1.0.2.0-DtLhCS1yMgY3iFYZkoZd12 binary-0.8.9.1
    bytestring-0.11.5.3
    cabal-install-parsers-0.6-LWHzSe1j8KR8DP6RtppZJz containers-0.6.7
    cryptohash-sha256-0.11.102.1-JuksYLM6warBHNj9levj9A deepseq-1.4.8.0
    directory-1.3.7.1 exceptions-0.10.5 filepath-1.4.2.2
    generic-lens-lite-0.1.1-fdAG00wdys4njg4MryBwd
    indexed-traversable-0.1.4-GkGrJgji2sS1heT6R1yu0
    indexed-traversable-instances-0.1.2-J10VAQpi6iaDNWyEbNVz6H
    ini-0.4.2-BGaXGCJ101cG4c9KbTBv1Q
    lattices-2.2.1-GTc91jsEAV9EAulmV3UzfU mtl-2.2.2
    network-uri-2.6.4.2-2s4BpOjYszS9lLOXbJJXzp
    optparse-applicative-0.18.1.0-DiZJ1DIwWjI1ByXXnUKInq
    parsec-3.1.16.1 pretty-1.1.3.6 process-1.6.18.0
    temporary-1.3-2XtnvHABNGf511WcFrV1ai text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-FFF0GulGLFtAHq6N1Lkm0s
    zinza-0.2-2RUDzDzDaGA12PsHRXojyd

haddock-interfaces:   /usr/share/doc/haskell-ci/html/haskell-ci.haddock
haddock-html:         /usr/share/doc/haskell-ci/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ci-0.16.3-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ci.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-haskell-ci-z-haskell-ci-internal
version:              0.16.3
package-name:         haskell-ci
lib-name:             haskell-ci-internal
id:
    haskell-ci-0.16.3-3FXcswsaFe6AFcESV7wkuB-haskell-ci-internal

key:
    haskell-ci-0.16.3-3FXcswsaFe6AFcESV7wkuB-haskell-ci-internal

license:              GPL-3.0-or-later
maintainer:           hvr@gnu.org
author:               Herbert Valerio Riedel, Oleg Grenrus
homepage:             https://haskell-ci.rtfd.org/
synopsis:             Cabal package script generator for Travis-CI
description:
    Script generator (@haskell-ci@) for
    [GitHub Actions](https://docs.github.com/en/actions) and
    [Travis-CI](https://travis-ci.org/)
    for continuous-integration testing of Haskell Cabal packages.

    Included features (not limited to):

    * Multiple GHC support
    * Dependency caching
    * cabal.project support (see [Nix-style local builds documentation](https://cabal.readthedocs.io/en/latest/nix-local-build-overview.html))
    * Runs tests and builds benchmarks
    * Generates Haddocks
    * GHCJS support
    * building with specific constraints

    === Quick Start Guide

    Add a @tested-with@ line to your @.cabal@ file (e.g. @tested-with: GHC == 8.0.2 || == 8.2.2@) and then run @haskell-ci yourpackage.cabal -o .travis.yml@ to generate the Travis-CI job script.

    See @haskell-ci --help@ for more information.

category:             Development
abi:                  546943757633326a00e3629256905062
exposed-modules:
    HaskellCI HaskellCI.Auxiliary HaskellCI.Bash
    HaskellCI.Bash.Template HaskellCI.Cabal HaskellCI.Cli
    HaskellCI.Compiler HaskellCI.Config HaskellCI.Config.Components
    HaskellCI.Config.ConstraintSet HaskellCI.Config.CopyFields
    HaskellCI.Config.Docspec HaskellCI.Config.Doctest
    HaskellCI.Config.Dump HaskellCI.Config.Empty HaskellCI.Config.Folds
    HaskellCI.Config.HLint HaskellCI.Config.Installed
    HaskellCI.Config.Jobs HaskellCI.Config.PackageScope
    HaskellCI.Config.Ubuntu HaskellCI.Config.Validity
    HaskellCI.Diagnostics HaskellCI.Error HaskellCI.Ghcup
    HaskellCI.GitConfig HaskellCI.GitHub HaskellCI.GitHub.Yaml
    HaskellCI.HeadHackage HaskellCI.Jobs HaskellCI.List
    HaskellCI.MonadErr HaskellCI.Newtypes HaskellCI.OptionsGrammar
    HaskellCI.OptparseGrammar HaskellCI.Package HaskellCI.ParsecUtils
    HaskellCI.Prelude HaskellCI.Sh HaskellCI.ShVersionRange
    HaskellCI.TestedWith HaskellCI.Tools HaskellCI.Travis
    HaskellCI.Travis.Yaml HaskellCI.VersionInfo HaskellCI.YamlSyntax

import-dirs:          /usr/lib/ghc-9.4.8/site-local/haskell-ci-0.16.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/haskell-ci-0.16.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/haskell-ci-0.16.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ci
hs-libraries:
    HShaskell-ci-0.16.3-3FXcswsaFe6AFcESV7wkuB-haskell-ci-internal

depends:
    Cabal-syntax-3.8.1.0 HsYAML-0.2.1.4-AlSCW7kgkmh8JPmVhyxalC
    ShellCheck-0.11.0-8N31zfwRoa26MHqYFHHdBe
    aeson-2.1.2.1-8gRdOgbBkF57DAEniCzHis
    attoparsec-0.14.4-BuoYNqKkZ0cK5gzfHXNsJW base-4.17.2.1
    base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp
    base16-bytestring-1.0.2.0-C3cPjjLt0AO1rbHXbT6P0Z binary-0.8.9.1
    bytestring-0.11.5.3
    cabal-install-parsers-0.6-3QY3qKTXDCU8uejU5SnKJG containers-0.6.7
    cryptohash-sha256-0.11.102.1-qCC3j6usTK8QvKkToMNCt deepseq-1.4.8.0
    directory-1.3.7.1 exceptions-0.10.5 filepath-1.4.2.2
    generic-lens-lite-0.1.1-fdAG00wdys4njg4MryBwd
    indexed-traversable-0.1.4-2T176InstcMqAaY6WCojl
    indexed-traversable-instances-0.1.2-Dp41K1CJgQbA1l6gXnWHNf
    ini-0.4.2-KpXFZk7uKrP3BRwyoeVMHP
    lattices-2.2.1-LQVIYTT1H4EDWZH2HZKTBL mtl-2.2.2
    network-uri-2.6.4.2-6QHuxl9r30A5vsu5UpWUoB
    optparse-applicative-0.18.1.0-HLRS0wxhkSb4kVPN7e82uH
    parsec-3.1.16.1 pretty-1.1.3.6 process-1.6.18.0
    temporary-1.3-DODaRJ5BM8m1pCh7H7okdb text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-obNV32ZSreHxgWRz6JrKP
    zinza-0.2-B9hImZpPPgbAJUxHyf47ZE

haddock-interfaces:   /usr/share/doc/haskell-ci/html/haskell-ci.haddock
haddock-html:         /usr/share/doc/haskell-ci/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
